@@ -9,3 +9,5 @@ from pjplan.io import TaskRaw
 from pjplan.io.df_io import to_df
 from pjplan.io.csv_io import read_csv, write_csv
 from pjplan.viz.tasksheet import task_sheet
+from pjplan.viz.dhtmlx.dhtmlx import DhtmlxTemplate
+from pjplan.viz.mermaid import mermaid_gantt, mermaid_network_diagram
\ No newline at end of file
