@@ -41,6 +41,17 @@ class TestWBS(TestCase):
 
         self.assertEqual(2, len(wbs))
 
+    def test_change_field(self):
+        wbs = WBS()
+        wbs // Task(1, "1", resource='1')
+        wbs // Task(2, "2", resource='2')
+        wbs // Task(3, "3", resource='2')
+
+        wbs(resource='2').resource='1'
+
+        self.assertEqual('1', wbs(2).resource)
+        self.assertEqual('1', wbs(3).resource)
+
     def test_clone(self):
 
         prj = WBS('0')
